@@ -1,9 +1,10 @@
 ### R code from vignette source 'SimInf.Rnw'
+### Encoding: UTF-8
 
 ###################################################
 ### code chunk number 1: SimInf.Rnw:108-109
 ###################################################
-options(prompt = "R> ", continue = "+    ", width = 74, useFancyQuotes = FALSE)
+options(prompt = "R> ", continue = "+  ", width = 70, useFancyQuotes = FALSE)
 
 
 ###################################################
@@ -96,38 +97,38 @@ events
 ###################################################
 u0 <- data.frame(S = rep(0, 5), I = rep(0, 5), R = rep(0, 5))
 add <- data.frame(event = "enter", time = rep(1:10, each = 5),
-node = 1:5, dest = 0, n = 1:5, proportion = 0, select = 1, shift = 0)
+  node = 1:5, dest = 0, n = 1:5, proportion = 0, select = 1, shift = 0)
 
 
 ###################################################
 ### code chunk number 15: SIR-infect
 ###################################################
 infect <- data.frame(event = "enter", time = 25, node = 5,
-dest = 0, n = 1, proportion = 0, select = 2, shift = 0)
+  dest = 0, n = 1, proportion = 0, select = 2, shift = 0)
 
 
 ###################################################
 ### code chunk number 16: SIR-move
 ###################################################
-move <- data.frame(event = "extTrans", time = 35:45,
-node = c(5, 5, 5, 5, 4, 4, 4, 3, 3, 2, 1), dest = c(4, 3, 3, 1, 3,
-2, 1, 2, 1, 1, 2), n = 5, proportion = 0, select = 4, shift = 0)
+move <- data.frame(event = "extTrans", time = 35:45, node = c(5, 5, 5,
+  5, 4, 4, 4, 3, 3, 2, 1), dest = c(4, 3, 3, 1, 3, 2, 1, 2, 1, 1, 2),
+  n = 5, proportion = 0, select = 4, shift = 0)
 
 
 ###################################################
 ### code chunk number 17: SIR-remove
 ###################################################
 remove <- data.frame(event = "exit", time = c(70, 110),
-node = rep(1:5, each = 2), dest = 0, n = 0, proportion = 0.2,
-select = 4, shift = 0)
+  node = rep(1:5, each = 2), dest = 0, n = 0, proportion = 0.2,
+  select = 4, shift = 0)
 
 
 ###################################################
-### code chunk number 18: SimInf.Rnw:1331-1337 (eval = FALSE)
+### code chunk number 18: SimInf.Rnw:1321-1327 (eval = FALSE)
 ###################################################
 ## events = rbind(add, infect, move, remove)
 ## model <- SIR(u0 = u0, tspan = 1:180, events = events, beta = 0.16,
-## gamma = 0.077)
+##   gamma = 0.077)
 ## set.seed(3)
 ## result <- run(model, threads = 1)
 ## plot(result, node = 1:5, range = FALSE)
@@ -160,13 +161,7 @@ dev.off()
 
 
 ###################################################
-### code chunk number 21: SimInf.Rnw:1383-1384
-###################################################
-options(continue = "+  ")
-
-
-###################################################
-### code chunk number 22: SIR-replicate
+### code chunk number 21: SIR-replicate
 ###################################################
 set.seed(123)
 mean(replicate(n = 1000, {
@@ -176,13 +171,7 @@ mean(replicate(n = 1000, {
 
 
 ###################################################
-### code chunk number 23: SimInf.Rnw:1395-1396
-###################################################
-options(continue = "+    ")
-
-
-###################################################
-### code chunk number 24: load-SISe_sp-data
+### code chunk number 22: load-SISe_sp-data
 ###################################################
 data("nodes", package = "SimInf")
 u0 <- u0_SISe()
@@ -190,13 +179,13 @@ events <- events_SISe()
 
 
 ###################################################
-### code chunk number 25: distance-matrix
+### code chunk number 23: distance-matrix
 ###################################################
 d_ik <- distance_matrix(x = nodes$x, y = nodes$y, cutoff = 2500)
 
 
 ###################################################
-### code chunk number 26: create-SISesp-u0
+### code chunk number 24: create-SISesp-u0
 ###################################################
 set.seed(123)
 i <- sample(x = 1:1600, size = 160)
@@ -205,20 +194,20 @@ u0$S[i] <- u0$S[i] - u0$I[i]
 
 
 ###################################################
-### code chunk number 27: create-SISesp-model
+### code chunk number 25: create-SISesp-model
 ###################################################
 model <- SISe_sp(u0 = u0, tspan = 1:1460, events = events, phi = 0,
-upsilon = 0.012, gamma = 0.1, alpha = 1, beta_t1 = 0.10,
-beta_t2 = 0.12, beta_t3 = 0.12, beta_t4 = 0.10, end_t1 = 91,
-end_t2 = 182, end_t3 = 273, end_t4 = 365, distance = d_ik,
-coupling = 0.2)
+  upsilon = 0.012, gamma = 0.1, alpha = 1, beta_t1 = 0.10,
+  beta_t2 = 0.12, beta_t3 = 0.12, beta_t4 = 0.10, end_t1 = 91,
+  end_t2 = 182, end_t3 = 273, end_t4 = 365, distance = d_ik,
+  coupling = 0.2)
 
 
 ###################################################
-### code chunk number 28: SimInf.Rnw:1528-1536 (eval = FALSE)
+### code chunk number 26: SimInf.Rnw:1510-1518 (eval = FALSE)
 ###################################################
-## plot(NULL, xlim = c(0, 1500), ylim = c(0, 0.18),
-## ylab = "Prevalance", xlab = "Time")
+## plot(NULL, xlim = c(0, 1500), ylim = c(0, 0.18), ylab = "Prevalance",
+##   xlab = "Time")
 ## set.seed(123)
 ## replicate(5, {
 ##   result <- run(model = model, threads = 1)
@@ -228,7 +217,7 @@ coupling = 0.2)
 
 
 ###################################################
-### code chunk number 29: SimInf.Rnw:1545-1551 (eval = FALSE)
+### code chunk number 27: SimInf.Rnw:1527-1533 (eval = FALSE)
 ###################################################
 ## gdata(model, "coupling") <- 0.1
 ## replicate(5, {
@@ -239,23 +228,23 @@ coupling = 0.2)
 
 
 ###################################################
-### code chunk number 30: SIR-mparse-I
+### code chunk number 28: SIR-mparse-I
 ###################################################
 transitions <- c("S -> b*S*I/(S+I+R) -> I", "I -> g*I -> R")
 compartments <- c("S", "I", "R")
 
 
 ###################################################
-### code chunk number 31: SIR-mparse-II
+### code chunk number 29: SIR-mparse-II
 ###################################################
 n <- 1000
 u0 <- data.frame(S = rep(99, n), I = rep(5, n), R = rep(0, n))
 model <- mparse(transitions = transitions, compartments = compartments,
-gdata = c(b = 0.16, g = 0.077), u0 = u0, tspan = 1:180)
+  gdata = c(b = 0.16, g = 0.077), u0 = u0, tspan = 1:180)
 
 
 ###################################################
-### code chunk number 32: SIR-mparse-III (eval = FALSE)
+### code chunk number 30: SIR-mparse-III (eval = FALSE)
 ###################################################
 ## set.seed(123)
 ## result <- run(model = model, threads = 1)
@@ -263,7 +252,7 @@ gdata = c(b = 0.16, g = 0.077), u0 = u0, tspan = 1:180)
 
 
 ###################################################
-### code chunk number 33: SIR-mparse-IV
+### code chunk number 31: SIR-mparse-IV
 ###################################################
 set.seed(123)
 result <- run(model = model, threads = 1)
@@ -271,26 +260,26 @@ plot(result)
 
 
 ###################################################
-### code chunk number 34: SIR-mparse-incidence (eval = FALSE)
+### code chunk number 32: SIR-mparse-incidence (eval = FALSE)
 ###################################################
 ## transitions <- c("S -> b*S*I/(S+I+R) -> I + Icum", "I -> g*I -> R")
 ## compartments <- c("S", "I", "Icum", "R")
 
 
 ###################################################
-### code chunk number 35: SIR-mparse-incidence-run (eval = FALSE)
+### code chunk number 33: SIR-mparse-incidence-run (eval = FALSE)
 ###################################################
 ## n <- 1000
 ## u0 <- data.frame(S = rep(99, n), I = rep(1, n), Icum = rep(0, n),
-## R = rep(0, n))
+##   R = rep(0, n))
 ## model <- mparse(transitions = transitions, compartments = compartments,
-## gdata = c(b = 0.16, g = 0.077), u0 = u0, tspan = 1:150)
+##   gdata = c(b = 0.16, g = 0.077), u0 = u0, tspan = 1:150)
 ## set.seed(123)
 ## result <- run(model = model, threads = 1)
 
 
 ###################################################
-### code chunk number 36: SIR-mparse-incidence-trajectory (eval = FALSE)
+### code chunk number 34: SIR-mparse-incidence-trajectory (eval = FALSE)
 ###################################################
 ## traj <- trajectory(model = result, compartments = "Icum")
 ## cases <- stepfun(result@tspan[-1], diff(c(0, traj$Icum[traj$node == 1])))
@@ -298,15 +287,15 @@ plot(result)
 
 
 ###################################################
-### code chunk number 37: SIR-mparse-incidence-plot (eval = FALSE)
+### code chunk number 35: SIR-mparse-incidence-plot (eval = FALSE)
 ###################################################
 ## plot(cases, main = "", xlab = "Time", ylab = "Number of cases",
-## do.points = FALSE)
+##   do.points = FALSE)
 ## lines(avg_cases, col = "blue", lwd = 2, lty = 2)
 
 
 ###################################################
-### code chunk number 38: SIR-mparse-incidence-plot
+### code chunk number 36: SIR-mparse-incidence-plot
 ###################################################
 transitions <- c("S -> b*S*I/(S+I+R) -> I + Icum", "I -> g*I -> R")
 compartments <- c("S", "I", "Icum", "R")
@@ -326,14 +315,14 @@ lines(avg_cases, col = "blue", lwd = 2, lty = 2)
 
 
 ###################################################
-### code chunk number 39: mparse-scheduled-events
+### code chunk number 37: mparse-scheduled-events
 ###################################################
 transitions <- c("S -> b*S*I/(S+I+R+V) -> I + Icum", "I -> g*I -> R")
 compartments <- c("S", "I", "Icum", "R", "V")
 
 
 ###################################################
-### code chunk number 40: mparse-scheduled-events-data
+### code chunk number 38: mparse-scheduled-events-data
 ###################################################
 u0 <- u0_SIR()
 u0$Icum <- 0
@@ -342,37 +331,31 @@ events <- events_SIR()
 
 
 ###################################################
-### code chunk number 41: mparse-scheduled-events-vaccination
+### code chunk number 39: mparse-scheduled-events-vaccination
 ###################################################
-vaccination <- data.frame(event = "intTrans", time = rep(21:52, each = 50),
-node = 1:1600, dest = 0, n = 0, proportion = 0.8, select = 3,
-shift = 1)
+vaccination <- data.frame(event = "intTrans", time = rep(21:52,
+  each = 50), node = 1:1600, dest = 0, n = 0, proportion = 0.8,
+  select = 3, shift = 1)
 
 
 ###################################################
-### code chunk number 42: mparse-scheduled-events-E-N
+### code chunk number 40: mparse-scheduled-events-E-N
 ###################################################
 E <- matrix(c(1, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 0, 1, 0), nrow = 5,
-ncol = 3, dimnames = list(c("S", "I", "Icum", "R", "V"),
-c("1", "2", "3")))
+  ncol = 3, dimnames = list(c("S", "I", "Icum", "R", "V"),
+  c("1", "2", "3")))
 N <- matrix(c(4, 3, 0, 1, 0), nrow = 5, ncol = 1,
-dimnames = list(c("S", "I", "Icum", "R", "V"), "1"))
+  dimnames = list(c("S", "I", "Icum", "R", "V"), "1"))
 
 
 ###################################################
-### code chunk number 43: mparse-recode-events
+### code chunk number 41: mparse-recode-events
 ###################################################
 events$select[events$select == 4] <- 2
 
 
 ###################################################
-### code chunk number 44: SimInf.Rnw:1854-1855
-###################################################
-options(continue = "+  ")
-
-
-###################################################
-### code chunk number 45: mparse-scheduled-events-epicurve
+### code chunk number 42: mparse-scheduled-events-epicurve
 ###################################################
 epicurve <- function(model, n = 1000) {
   Icum <- numeric(length(model@tspan))
@@ -392,83 +375,77 @@ epicurve <- function(model, n = 1000) {
 
 
 ###################################################
-### code chunk number 46: SimInf.Rnw:1876-1877
-###################################################
-options(continue = "+    ")
-
-
-###################################################
-### code chunk number 47: mparse-scheduled-events-model-no-vac (eval = FALSE)
+### code chunk number 43: mparse-scheduled-events-model-no-vac (eval = FALSE)
 ###################################################
 ## model_no_vac <- mparse(transitions = transitions,
-## compartments = compartments, gdata = c(b = 0.16, g = 0.077),
-## u0 = u0, tspan = 1:300, events = events, E = E, N = N)
+##   compartments = compartments, gdata = c(b = 0.16, g = 0.077),
+##   u0 = u0, tspan = 1:300, events = events, E = E, N = N)
 ## cases_no_vac <- epicurve(model_no_vac)
 
 
 ###################################################
-### code chunk number 48: mparse-scheduled-events-model-vac (eval = FALSE)
+### code chunk number 44: mparse-scheduled-events-model-vac (eval = FALSE)
 ###################################################
 ## model_vac <- mparse(transitions = transitions,
-## compartments = compartments, gdata = c(b = 0.16, g = 0.077),
-## u0 = u0, tspan = 1:300, events = rbind(events, vaccination),
-## E = E, N = N)
+##   compartments = compartments, gdata = c(b = 0.16, g = 0.077),
+##   u0 = u0, tspan = 1:300, events = rbind(events, vaccination),
+##   E = E, N = N)
 ## cases_vac <- epicurve(model_vac)
 
 
 ###################################################
-### code chunk number 49: mparse-scheduled-events-plot (eval = FALSE)
+### code chunk number 45: mparse-scheduled-events-plot (eval = FALSE)
 ###################################################
 ## plot(cases_no_vac, main = "", xlim = c(0, 300), xlab = "Time",
-## ylab = "Number of cases", do.points = FALSE)
+##   ylab = "Number of cases", do.points = FALSE)
 ## lines(cases_vac, col = "blue", do.points = FALSE, lty = 2)
 ## abline(v = 21, col = "red", lty = 3)
 ## legend("topright", c("No vaccination", "Vaccination"),
-## col = c("black", "blue"), lty = 1:2)
+##   col = c("black", "blue"), lty = 1:2)
 
 
 ###################################################
-### code chunk number 50: mparse-predator-prey-I
+### code chunk number 46: mparse-predator-prey-I
 ###################################################
 transitions <- c("@ -> bR*R -> R", "R -> (dR+(bR-dR)*R/K)*R -> @",
-"R -> alpha/(1+w*R)*R*F -> @", "@ -> bF*alpha/(1+w*R)*R*F -> F",
-"F -> dF*F -> @")
+  "R -> alpha/(1+w*R)*R*F -> @", "@ -> bF*alpha/(1+w*R)*R*F -> F",
+  "F -> dF*F -> @")
 compartments <- c("R", "F")
 parameters <- c(bR = 2, bF = 2, dR = 1, K = 1000, alpha = 0.007,
-w = 0.0035, dF = 2)
+  w = 0.0035, dF = 2)
 
 
 ###################################################
-### code chunk number 51: mparse-predator-prey-II
+### code chunk number 47: mparse-predator-prey-II
 ###################################################
 n <- 1000
 u0 = data.frame(R = rep(1000, n), F = rep(100, n))
 model <- mparse(transitions = transitions, compartments = compartments,
-gdata = parameters, u0 = u0, tspan = 1:100)
+  gdata = parameters, u0 = u0, tspan = 1:100)
 
 
 ###################################################
-### code chunk number 52: create-package-skeleton (eval = FALSE)
+### code chunk number 48: create-package-skeleton (eval = FALSE)
 ###################################################
 ## path <- tempdir()
 ## package_skeleton(model = model, name = "PredatorPrey", path = path)
 
 
 ###################################################
-### code chunk number 53: install-package-skeleton (eval = FALSE)
+### code chunk number 49: install-package-skeleton (eval = FALSE)
 ###################################################
 ## pkg <- file.path(path, "PredatorPrey")
 ## install.packages(pkg, repos = NULL, type = "source")
 
 
 ###################################################
-### code chunk number 54: load-predator-prey (eval = FALSE)
+### code chunk number 50: load-predator-prey (eval = FALSE)
 ###################################################
 ## library("PredatorPrey")
 
 
 ###################################################
-### code chunk number 55: create-predator-prey-model (eval = FALSE)
+### code chunk number 51: create-predator-prey-model (eval = FALSE)
 ###################################################
 ## model <- PredatorPrey(u0 = u0, tspan = 1:100, gdata = parameters)
 ## set.seed(123)
@@ -476,14 +453,14 @@ gdata = parameters, u0 = u0, tspan = 1:100)
 
 
 ###################################################
-### code chunk number 56: predator-prey-plot (eval = FALSE)
+### code chunk number 52: predator-prey-plot (eval = FALSE)
 ###################################################
 ## opar <- par(mfrow = c(1, 2))
 ## plot(R ~ F, trajectory(model = result), cex = 0.3, pch = 20,
-## xlab = "Number of predators", ylab = "Number of prey",
-## col = rgb(0, 0, 0, alpha = 0.1))
+##   xlab = "Number of predators", ylab = "Number of prey",
+##   col = rgb(0, 0, 0, alpha = 0.1))
 ## plot(R ~ time, trajectory(model = result, node = 4), type = "l",
-## xlab = "Time", ylab = "N")
+##   xlab = "Time", ylab = "N")
 ## lines(F ~ time, trajectory(model = result, node = 4), type = "l", lty = 2)
 ## legend("right", c("Prey", "Predator"), lty = 1:2)
 ## par(opar)
