@@ -1,7 +1,7 @@
 ## SimInf, a framework for stochastic disease spread simulations
 ## Copyright (C) 2015  Pavol Bauer
-## Copyright (C) 2015 - 2017  Stefan Engblom
-## Copyright (C) 2015 - 2017  Stefan Widgren
+## Copyright (C) 2015 - 2018  Stefan Engblom
+## Copyright (C) 2015 - 2018  Stefan Widgren
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -79,6 +79,26 @@ stopifnot(length(
     grep("Invalid 'phi': must be numeric vector with non-negative values",
          res[[1]]$message)) > 0)
 
+res <- SISe(u0      = u0,
+            tspan   = seq_len(10) - 1,
+            events  = NULL,
+            upsilon = 0.0357,
+            gamma   = 0.1,
+            alpha   = 1.0,
+            beta_t1 = 0.19,
+            beta_t2 = 0.085,
+            beta_t3 = 0.075,
+            beta_t4 = 0.185,
+            end_t1  = 91,
+            end_t2  = 182,
+            end_t3  = 273,
+            end_t4  = 365,
+            epsilon = 0.000011)
+stopifnot(identical(res@v0,
+                    structure(c(0, 0, 0, 0, 0, 0),
+                              .Dim = c(1L, 6L),
+                              .Dimnames = list("phi", NULL))))
+
 ## Check missing upsilon
 res <- tools::assertError(SISe(u0      = u0,
                                tspan   = seq_len(10) - 1,
