@@ -25,14 +25,27 @@ res <- tools::assertError(package_skeleton())
 stopifnot(length(grep("Missing 'model' argument",
                       res[[1]]$message)) > 0)
 res <- tools::assertError(package_skeleton(5))
-stopifnot(length(grep("'model' argument is not a 'SimInf_model' object",
+stopifnot(length(grep("'model' argument is not a 'SimInf_model'",
                       res[[1]]$message)) > 0)
 
-## Chack package_skeleton
-m <- mparse(transitions = c("S -> b*S*I/(S+I+R) -> I", "I -> g*I -> R"),
+## Check missing 'ldata', 'gdata' and 'v0' parameters
+m <- mparse(transitions = "@ -> 1 -> S",
+            compartments = "S",
+            u0 = data.frame(S = 0),
+            tspan = 1:10)
+stopifnot(is.null(SimInf:::create_model_R_object_ldata(m)))
+stopifnot(is.null(SimInf:::create_model_R_object_gdata(m)))
+stopifnot(is.null(SimInf:::create_model_R_object_v0(m)))
+
+## Check package_skeleton
+m <- mparse(transitions = c("@ -> a -> S",
+                            "S -> b*S*I/(S+I+R) -> I",
+                            "I -> g*I -> R"),
             compartments = c("S", "I", "R"),
-            gdata = c(b = 0.16, g = 0.077),
+            ldata = data.frame(a = 1),
+            gdata = c(b = 0.16),
             u0 = data.frame(S = 99, I = 1, R = 0),
+            v0 = data.frame(g = 0.077),
             tspan = 1:10)
 
 path <- tempdir()
