@@ -16,7 +16,7 @@
 ## You should have received a copy of the GNU General Public License
 ## along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-library(SimInf)
+library("SimInf")
 
 ## For debugging
 sessionInfo()
@@ -79,19 +79,27 @@ sis_e <- SISe(u0      = data.frame(S = 100, I = 0),
               epsilon = 0.000011)
 
 sis_e <- run(sis_e, threads = 1)
-sis_e_phi_obs <- V(sis_e)[1,]
+sis_e_phi_obs <- trajectory(sis_e, "phi", as.is = TRUE)[1,]
 stopifnot(all(abs(sis_e_phi_obs - phi_exp) < tol))
+sis_e_phi_obs <- trajectory(sis_e, "phi")$phi
+stopifnot(all(abs(sis_e_phi_obs - as.numeric(phi_exp)) < tol))
 
 ## Run with sparse V
-V(sis_e) <- as(phi_exp, "dgCMatrix")
+V(sis_e) <- data.frame(time = seq(from = 1, to = 700, by = 7),
+                       node = 1,
+                       phi = TRUE)
 sis_e <- run(sis_e, threads = 1)
-sis_e_phi_obs <- V(sis_e)[1,]
+sis_e_phi_obs <- trajectory(sis_e, "phi", as.is = TRUE)[1,]
 stopifnot(all(abs(sis_e_phi_obs - phi_exp) < tol))
+sis_e_phi_obs <- trajectory(sis_e, "phi")$phi
+stopifnot(all(abs(sis_e_phi_obs - as.numeric(phi_exp)) < tol))
 
 if (SimInf:::have_openmp()) {
     sis_e <- run(sis_e, threads = 2)
-    sis_e_phi_obs <- V(sis_e)[1,]
+    sis_e_phi_obs <- trajectory(sis_e, "phi", as.is = TRUE)[1,]
     stopifnot(all(abs(sis_e_phi_obs - phi_exp) < tol))
+    sis_e_phi_obs <- trajectory(sis_e, "phi")$phi
+    stopifnot(all(abs(sis_e_phi_obs - as.numeric(phi_exp)) < tol))
 }
 
 ## Check phi from the SISe3 model
@@ -119,17 +127,25 @@ sis_e3 <- SISe3(u0      = data.frame(S_1 = 10, I_1 = 0,
                 epsilon   = 0.000011)
 
 sis_e3 <- run(sis_e3, threads = 1)
-sis_e3_phi_obs <- V(sis_e3)[1,]
+sis_e3_phi_obs <- trajectory(sis_e3, "phi", as.is = TRUE)[1,]
 stopifnot(all(abs(sis_e3_phi_obs - phi_exp) < tol))
+sis_e3_phi_obs <- trajectory(sis_e3, "phi")$phi
+stopifnot(all(abs(sis_e3_phi_obs - as.numeric(phi_exp)) < tol))
 
 ## Run with sparse V
-V(sis_e3) <- as(phi_exp, "dgCMatrix")
+V(sis_e3) <- data.frame(time = seq(from = 1, to = 700, by = 7),
+                        node = 1,
+                        phi = TRUE)
 sis_e3 <- run(sis_e3, threads = 1)
-sis_e3_phi_obs <- V(sis_e3)[1,]
+sis_e3_phi_obs <- trajectory(sis_e3, "phi", as.is = TRUE)[1,]
 stopifnot(all(abs(sis_e3_phi_obs - phi_exp) < tol))
+sis_e3_phi_obs <- trajectory(sis_e3, "phi")$phi
+stopifnot(all(abs(sis_e3_phi_obs - as.numeric(phi_exp)) < tol))
 
 if (SimInf:::have_openmp()) {
     sis_e3 <- run(sis_e3, threads = 2)
-    sis_e3_phi_obs <- V(sis_e3)[1,]
+    sis_e3_phi_obs <- trajectory(sis_e3, "phi", as.is = TRUE)[1,]
     stopifnot(all(abs(sis_e3_phi_obs - phi_exp) < tol))
+    sis_e3_phi_obs <- trajectory(sis_e3, "phi")$phi
+    stopifnot(all(abs(sis_e3_phi_obs - as.numeric(phi_exp)) < tol))
 }
